@@ -26,6 +26,7 @@ from curtin.log import LOG
 
 NOSPARE_RAID_LEVELS = [
     'linear', 'raid0', '0', 0,
+    'container'
 ]
 
 SPARE_RAID_LEVELS = [
@@ -145,8 +146,8 @@ def mdadm_assemble(md_devname=None, devices=[], spares=[], scan=False,
     udev.udevadm_settle()
 
 
-def mdadm_create(md_devname, raidlevel, devices, spares=None, md_name="",
-                 metadata=None):
+def mdadm_create(md_devname, raidlevel, devices, spares=None, container=None,
+                 md_name="", metadata=None):
     LOG.debug('mdadm_create: ' +
               'md_name=%s raidlevel=%s ' % (md_devname, raidlevel) +
               ' devices=%s spares=%s name=%s' % (devices, spares, md_name))
@@ -159,8 +160,11 @@ def mdadm_create(md_devname, raidlevel, devices, spares=None, md_name="",
         raise ValueError('Invalid raidlevel: [{}]'.format(raidlevel))
 
     min_devices = md_minimum_devices(raidlevel)
-    if len(devices) < min_devices:
-        err = 'Not enough devices for raidlevel: ' + str(raidlevel)
+    devcnt = len(devices) if not container else \
+        len(md_get_devices_list(container))
+    if devcnt < min_devices:
+        err = 'Not enough devices (' + str(devcnt) + ') '
+        err += 'for raidlevel: ' + str(raidlevel)
         err += ' minimum devices needed: ' + str(min_devices)
         raise ValueError(err)
 
@@ -171,13 +175,20 @@ def mdadm_create(md_devname, raidlevel, devices, spares=None, md_name="",
     (hostname, _err) = util.subp(["hostname", "-s"], rcs=[0], capture=True)
 
     cmd = ["mdadm", "--create", md_devname, "--run",
-           "--metadata=%s" % metadata,
            "--homehost=%s" % hostname.strip(),
-           "--level=%s" % raidlevel,
-           "--raid-devices=%s" % len(devices)]
+           "--raid-devices=%s" % devcnt]
+
+    if not container:
+        cmd.append("--metadata=%s" % metadata)
+    if raidlevel != 'container':
+        cmd.append("--level=%s" % raidlevel)
+
     if md_name:
         cmd.append("--name=%s" % md_name)
 
+    if container:
+        cmd.append(container)
+
     for device in devices:
         holders = get_holders(device)
         if len(holders) > 0:
@@ -508,7 +519,8 @@ def md_sysfs_attr(md_devname, attrname):
 
 
 def md_raidlevel_short(raidlevel):
-    if isinstance(raidlevel, int) or raidlevel in ['linear', 'stripe']:
+    if isinstance(raidlevel, int) or \
+       raidlevel in ['linear', 'stripe', 'container']:
         return raidlevel
 
     return int(raidlevel.replace('raid', ''))
@@ -517,7 +529,7 @@ def md_raidlevel_short(raidlevel):
 def md_minimum_devices(raidlevel):
     ''' return the minimum number of devices for a given raid level '''
     rl = md_raidlevel_short(raidlevel)
-    if rl in [0, 1, 'linear', 'stripe']:
+    if rl in [0, 1, 'linear', 'stripe', 'container']:
         return 2
     if rl in [5]:
         return 3
@@ -603,6 +615,11 @@ def __mdadm_detail_to_dict(input):
     # start after the first newline
     remainder = input[input.find('\n')+1:]
 
+    # keep only the first section (imsm container)
+    arraysection = remainder.find('\n[')
+    if arraysection != -1:
+        remainder = remainder[:arraysection]
+
     #  FIXME: probably could do a better regex to match the LHS which
     #         has one, two or three words
     rem = r'(\w+|\w+\ \w+|\w+\ \w+\ \w+)\ \:\ ([a-zA-Z0-9\-\.,: \(\)=\']+)'
@@ -837,4 +854,8 @@ def md_check(md_devname, raidlevel, devices=[], spares=[]):
     LOG.debug('RAID array OK: ' + md_devname)
     return True
 
+
+def md_is_in_container(md_devname):
+    return 'MD_CONTAINER' in mdadm_query_detail(md_devname)
+
 # vi: ts=4 expandtab syntax=python
