@@ -437,10 +437,6 @@ def get_path_to_storage_volume(volume, storage_config):
             volume_path = block.kname_to_path(partition_kname)
         devsync_vol = os.path.join(disk_block_path)
 
-    elif vol.get('type') == "dasd":
-        dasd_device = dasd.DasdDevice(vol.get('device_id'))
-        volume_path = dasd_device.devname
-
     elif vol.get('type') == "disk":
         # Get path to block device for disk. Device_id param should refer
         # to id of device in storage config
@@ -615,8 +611,7 @@ def disk_handler(info, storage_config):
             elif ptable in _dos_names:
                 util.subp(["parted", disk, "--script", "mklabel", "msdos"])
             elif ptable == "vtoc":
-                # ignore dasd partition tables
-                pass
+                util.subp(["fdasd", "-c", "/dev/null", disk])
         holders = clear_holders.get_holders(disk)
         if len(holders) > 0:
             LOG.info('Detected block holders on disk %s: %s', disk, holders)
@@ -668,18 +663,17 @@ def find_extended_partition(part_device, storage_config):
             return item_id
 
 
-def calc_dm_partition_info(partition):
-    # dm- partitions are not in the same dir as disk dm device,
-    # dmsetup table <dm_name>
-    # handle linear types only
-    #    mpatha-part1: 0 6291456 linear 253:0, 2048
-    #    <dm_name>: <log. start sec> <num sec> <type> <dest dev>  <start sec>
+def calc_dm_partition_info(partition_kname):
+    # finding the start of a dm partition appears to only be possible
+    # via parsing dmsetup output. the size is present in sysfs but
+    # given that it is included in the dmsetup output anyway, we take
+    # it from there too.
     #
-    # Mapping this:
-    #   previous_size_sectors = <num_sec> | /sys/class/block/dm-1/size
-    #   previous_start_sectors = <start_sec> |  No 'start' sysfs file
-    pp_size_sec = pp_start_sec = None
-    mpath_id = multipath.get_mpath_id_from_device(block.dev_path(partition))
+    # dmsetup table <dm_name>
+    #    mpatha-part1: 0 6291456 linear 253:0 2048
+    #    <dm_name>: <log. start sec> <num sec> <type> <dest dev>  <start sec>
+    mpath_id = multipath.get_mpath_id_from_device(
+        block.dev_path(partition_kname))
     if mpath_id is None:
         raise RuntimeError('Failed to find mpath_id for partition')
     table_cmd = ['dmsetup', 'table', '--target', 'linear', mpath_id]
@@ -687,32 +681,31 @@ def calc_dm_partition_info(partition):
     if out:
         (_logical_start, previous_size_sectors, _table_type,
          _destination, previous_start_sectors) = out.split()
-        pp_size_sec = int(previous_size_sectors)
-        pp_start_sec = int(previous_start_sectors)
-
-    return (pp_start_sec, pp_size_sec)
-
-
-def calc_partition_info(disk, partition, logical_block_size_bytes):
-    if partition.startswith('dm-'):
-        pp = partition
-        pp_start_sec, pp_size_sec = calc_dm_partition_info(partition)
+        return int(previous_start_sectors), int(previous_size_sectors)
     else:
-        pp = os.path.join(disk, partition)
-        # XXX: sys/block/X/{size,start} is *ALWAYS* in 512b value
-        pp_size = int(
-            util.load_file(os.path.join(pp, "size")))
-        pp_size_sec = int(pp_size * 512 / logical_block_size_bytes)
-        pp_start = int(util.load_file(os.path.join(pp, "start")))
-        pp_start_sec = int(pp_start * 512 / logical_block_size_bytes)
+        raise RuntimeError('Failed to find mpath_id for partition')
 
-    LOG.debug("previous partition: %s size_sectors=%s start_sectors=%s",
-              pp, pp_size_sec, pp_start_sec)
-    if not all([pp_size_sec, pp_start_sec]):
+
+def calc_partition_info(partition_kname, logical_block_size_bytes):
+    if partition_kname.startswith('dm-'):
+        p_start, p_size = calc_dm_partition_info(partition_kname)
+    else:
+        pdir = block.sys_block_path(partition_kname)
+        p_size = int(util.load_file(os.path.join(pdir, "size")))
+        p_start = int(util.load_file(os.path.join(pdir, "start")))
+
+    # NB: sys/block/X/{size,start} and dmsetup output are both always
+    # in 512b sectors
+    p_size_sec = p_size * 512 // logical_block_size_bytes
+    p_start_sec = p_start * 512 // logical_block_size_bytes
+
+    LOG.debug("calc_partition_info: %s size_sectors=%s start_sectors=%s",
+              partition_kname, p_size_sec, p_start_sec)
+    if not all([p_size_sec, p_start_sec]):
         raise RuntimeError(
-            'Failed to determine previous partition %s info', partition)
+            'Failed to determine partition %s info', partition_kname)
 
-    return (pp_start_sec, pp_size_sec)
+    return (p_start_sec, p_size_sec)
 
 
 def verify_exists(devpath):
@@ -772,7 +765,7 @@ def verify_ptable_flag(devpath, expected_flag, sfdisk_info=None):
         raise RuntimeError(msg)
 
 
-def partition_verify(devpath, info):
+def partition_verify_sfdisk(devpath, info):
     verify_exists(devpath)
     sfdisk_info = block.sfdisk_info(devpath)
     if not sfdisk_info:
@@ -784,6 +777,21 @@ def partition_verify(devpath, info):
         verify_ptable_flag(devpath, info['flag'], sfdisk_info=sfdisk_info)
 
 
+def partition_verify_fdasd(disk_path, partnumber, info):
+    verify_exists(disk_path)
+    pt = dasd.DasdPartitionTable.from_fdasd(disk_path)
+    pt_entry = pt.partitions[partnumber-1]
+    expected_tracks = pt.tracks_needed(util.human2bytes(info['size']))
+    msg = (
+        'Verifying %s part %s size, expecting %s tracks, found %s tracks' % (
+         disk_path, partnumber, expected_tracks, pt_entry.length))
+    LOG.debug(msg)
+    if expected_tracks != pt_entry.length:
+        raise RuntimeError(msg)
+    if info.get('flag', 'linux') != 'linux':
+        raise RuntimeError("dasd partitions do not support flags")
+
+
 def partition_handler(info, storage_config):
     device = info.get('device')
     size = info.get('size')
@@ -798,7 +806,6 @@ def partition_handler(info, storage_config):
     disk = get_path_to_storage_volume(device, storage_config)
     partnumber = determine_partition_number(info.get('id'), storage_config)
     disk_kname = block.path_to_kname(disk)
-    disk_sysfs_path = block.sys_block_path(disk)
 
     # consider the disks logical sector size when calculating sectors
     try:
@@ -833,8 +840,7 @@ def partition_handler(info, storage_config):
         partition_kname = block.partition_kname(disk_kname, pnum)
         LOG.debug('partition_kname=%s', partition_kname)
         (previous_start_sectors, previous_size_sectors) = (
-            calc_partition_info(disk_sysfs_path, partition_kname,
-                                logical_block_size_bytes))
+            calc_partition_info(partition_kname, logical_block_size_bytes))
 
     # Align to 1M at the beginning of the disk and at logical partitions
     alignment_offset = int((1 << 20) / logical_block_size_bytes)
@@ -875,10 +881,15 @@ def partition_handler(info, storage_config):
     # Handle preserve flag
     create_partition = True
     if config.value_as_boolean(info.get('preserve')):
-        part_path = block.dev_path(
-            block.partition_kname(disk_kname, partnumber))
-        partition_verify(part_path, info)
-        LOG.debug('Partition %s already present, skipping create', part_path)
+        if disk_ptable == 'vtoc':
+            partition_verify_fdasd(disk, partnumber, info)
+        else:
+            part_path = block.dev_path(
+                block.partition_kname(disk_kname, partnumber))
+            partition_verify_sfdisk(part_path, info)
+        LOG.debug(
+            '%s partition %s already present, skipping create',
+            disk, partnumber)
         create_partition = False
 
     if create_partition:
@@ -933,9 +944,8 @@ def partition_handler(info, storage_config):
                    "--typecode=%s:%s" % (partnumber, typecode), disk]
             util.subp(cmd, capture=True)
         elif disk_ptable == "vtoc":
-            disk_device_id = storage_config.get(device).get('device_id')
-            dasd_device = dasd.DasdDevice(disk_device_id)
-            dasd_device.partition(partnumber, length_bytes)
+            dasd_pt = dasd.DasdPartitionTable.from_fdasd(disk)
+            dasd_pt.add_partition(partnumber, length_bytes)
         else:
             raise ValueError("parent partition has invalid partition table")
 
@@ -1486,21 +1496,30 @@ def raid_handler(info, storage_config):
     raidlevel = info.get('raidlevel')
     spare_devices = info.get('spare_devices')
     md_devname = block.md_path(info.get('name'))
+    container = info.get('container')
+    metadata = info.get('metadata')
     preserve = config.value_as_boolean(info.get('preserve'))
-    if not devices:
-        raise ValueError("devices for raid must be specified")
+    if not devices and not container:
+        raise ValueError("devices or container for raid must be specified")
     if raidlevel not in ['linear', 'raid0', 0, 'stripe', 'raid1', 1, 'mirror',
-                         'raid4', 4, 'raid5', 5, 'raid6', 6, 'raid10', 10]:
+                         'raid4', 4, 'raid5', 5, 'raid6', 6, 'raid10', 10,
+                         'container']:
         raise ValueError("invalid raidlevel '%s'" % raidlevel)
-    if raidlevel in ['linear', 'raid0', 0, 'stripe']:
+    if raidlevel in ['linear', 'raid0', 0, 'stripe', 'container']:
         if spare_devices:
             raise ValueError("spareunsupported in raidlevel '%s'" % raidlevel)
 
     LOG.debug('raid: cfg: %s', util.json_dumps(info))
-    device_paths = list(get_path_to_storage_volume(dev, storage_config) for
-                        dev in devices)
-    LOG.debug('raid: device path mapping: %s',
-              list(zip(devices, device_paths)))
+
+    container_dev = None
+    device_paths = []
+    if container:
+        container_dev = get_path_to_storage_volume(container, storage_config)
+    else:
+        device_paths = list(get_path_to_storage_volume(dev, storage_config) for
+                            dev in devices)
+        LOG.debug('raid: device path mapping: {}'.format(
+            zip(devices, device_paths)))
 
     spare_device_paths = []
     if spare_devices:
@@ -1517,8 +1536,8 @@ def raid_handler(info, storage_config):
 
     if create_raid:
         mdadm.mdadm_create(md_devname, raidlevel,
-                           device_paths, spare_device_paths,
-                           info.get('mdname', ''))
+                           device_paths, spare_device_paths, container_dev,
+                           info.get('mdname', ''), metadata)
 
     wipe_mode = info.get('wipe')
     if wipe_mode:
