@@ -157,9 +157,9 @@ class BionicTestMdadmBcache(relbase.bionic, TestMdadmBcacheAbs):
 class FocalTestMdadmBcache(relbase.focal, TestMdadmBcacheAbs):
     __test__ = True
 
-    @TestMdadmBcacheAbs.skip_by_date("1861941", fixby="2020-09-15")
-    def test_fstab(self):
-        return super().test_fstab()
+
+class HirsuteTestMdadmBcache(relbase.hirsute, TestMdadmBcacheAbs):
+    __test__ = True
 
 
 class GroovyTestMdadmBcache(relbase.groovy, TestMdadmBcacheAbs):
@@ -207,6 +207,10 @@ class FocalTestMirrorboot(relbase.focal, TestMirrorbootAbs):
     __test__ = True
 
 
+class HirsuteTestMirrorboot(relbase.hirsute, TestMirrorbootAbs):
+    __test__ = True
+
+
 class GroovyTestMirrorboot(relbase.groovy, TestMirrorbootAbs):
     __test__ = True
 
@@ -256,6 +260,11 @@ class FocalTestMirrorbootPartitions(relbase.focal,
     __test__ = True
 
 
+class HirsuteTestMirrorbootPartitions(relbase.hirsute,
+                                      TestMirrorbootPartitionsAbs):
+    __test__ = True
+
+
 class GroovyTestMirrorbootPartitions(relbase.groovy,
                                      TestMirrorbootPartitionsAbs):
     __test__ = True
@@ -351,6 +360,11 @@ class FocalTestMirrorbootPartitionsUEFI(relbase.focal,
     __test__ = True
 
 
+class HirsuteTestMirrorbootPartitionsUEFI(relbase.hirsute,
+                                          TestMirrorbootPartitionsUEFIAbs):
+    __test__ = True
+
+
 class GroovyTestMirrorbootPartitionsUEFI(relbase.groovy,
                                          TestMirrorbootPartitionsUEFIAbs):
     __test__ = True
@@ -400,6 +414,10 @@ class FocalTestRaid5boot(relbase.focal, TestRaid5bootAbs):
     __test__ = True
 
 
+class HirsuteTestRaid5boot(relbase.hirsute, TestRaid5bootAbs):
+    __test__ = True
+
+
 class GroovyTestRaid5boot(relbase.groovy, TestRaid5bootAbs):
     __test__ = True
 
@@ -461,6 +479,10 @@ class FocalTestRaid6boot(relbase.focal, TestRaid6bootAbs):
     __test__ = True
 
 
+class HirsuteTestRaid6boot(relbase.hirsute, TestRaid6bootAbs):
+    __test__ = True
+
+
 class GroovyTestRaid6boot(relbase.groovy, TestRaid6bootAbs):
     __test__ = True
 
@@ -508,6 +530,10 @@ class FocalTestRaid10boot(relbase.focal, TestRaid10bootAbs):
     __test__ = True
 
 
+class HirsuteTestRaid10boot(relbase.hirsute, TestRaid10bootAbs):
+    __test__ = True
+
+
 class GroovyTestRaid10boot(relbase.groovy, TestRaid10bootAbs):
     __test__ = True
 
@@ -612,6 +638,10 @@ class FocalTestAllindata(relbase.focal, TestAllindataAbs):
     __test__ = True
 
 
+class HirsuteTestAllindata(relbase.hirsute, TestAllindataAbs):
+    __test__ = True
+
+
 class GroovyTestAllindata(relbase.groovy, TestAllindataAbs):
     __test__ = True
 
