@@ -32,6 +32,10 @@ class FocalTestReuseRAIDMember(relbase.focal, TestReuseRAIDMember):
     __test__ = True
 
 
+class HirsuteTestReuseRAIDMember(relbase.hirsute, TestReuseRAIDMember):
+    __test__ = True
+
+
 class GroovyTestReuseRAIDMember(relbase.groovy, TestReuseRAIDMember):
     __test__ = True
 
@@ -46,6 +50,11 @@ class FocalTestReuseRAIDMemberPartition(relbase.focal,
     __test__ = True
 
 
+class HirsuteTestReuseRAIDMemberPartition(relbase.hirsute,
+                                          TestReuseRAIDMemberPartition):
+    __test__ = True
+
+
 class GroovyTestReuseRAIDMemberPartition(relbase.groovy,
                                          TestReuseRAIDMemberPartition):
     __test__ = True
